@@ -37,7 +37,9 @@ from tdw.FBOutput import Keyboard as Key
 from tdw.FBOutput import Magnebot as Mag
 from tdw.FBOutput import ScreenPosition as Screen
 from tdw.FBOutput import TriggerCollision as Trigger
+from tdw.FBOutput import LocalTransforms as LocalTran
 from tdw.FBOutput import DriveAxis, JointType
+from tdw.FBOutput import QuitSignal as QuitSig
 import numpy as np
 from typing import Tuple, Optional
 
@@ -1009,3 +1011,34 @@ class TriggerCollision(OutputData):
             return "stay"
         else:
             return "exit"
+
+
+class LocalTransforms(OutputData):
+    def get_data(self) -> LocalTran.LocalTransforms:
+        return LocalTran.LocalTransforms.GetRootAsLocalTransforms(self.bytes, 0)
+
+    def get_num(self) -> int:
+        return self.data.ObjectsLength()
+
+    def get_id(self, index: int) -> int:
+        return self.data.Objects(index).Id()
+
+    def get_position(self, index: int) -> Tuple[float, float, float]:
+        return OutputData._get_vector3(self.data.Objects(index).Position)
+
+    def get_forward(self, index: int) -> Tuple[float, float, float]:
+        return OutputData._get_vector3(self.data.Objects(index).Forward)
+
+    def get_eulers(self, index: int) -> Tuple[float, float, float]:
+        return OutputData._get_vector3(self.data.Objects(index).Eulers)
+
+    def get_rotation(self, index: int) -> Tuple[float, float, float, float]:
+        return OutputData._get_quaternion(self.data.Objects(index).Rotation)
+
+
+class QuitSignal(OutputData):
+    def get_data(self) -> QuitSig.QuitSignal:
+        return QuitSig.QuitSignal.GetRootAsQuitSignal(self.bytes, 0)
+
+    def get_ok(self) -> bool:
+        return self.data.Ok()
