@@ -730,6 +730,19 @@ class TDWUtils:
                 "back": np.array(bounds.get_back(index)),
                 "center": np.array(bounds.get_center(index))}
 
+    @staticmethod
+    def get_bounds_extents(bounds: Bounds, index: int) -> np.array:
+        """
+        :param bounds: Bounds output data.
+        :param index: The index in `bounds` of the target object.
+
+        :return: The width (left to right), length (front to back), and height (top to bottom) of the bounds as a numpy array.
+        """
+
+        return np.array([np.linalg.norm(np.array(bounds.get_left(index)) - np.array(bounds.get_right(index))),
+                         np.linalg.norm(np.array(bounds.get_front(index)) - np.array(bounds.get_back(index))),
+                         np.linalg.norm(np.array(bounds.get_top(index)) - np.array(bounds.get_bottom(index)))])
+
     @staticmethod
     def get_closest_position_in_bounds(origin: np.array, bounds: Bounds, index: int) -> np.array:
         """
@@ -816,6 +829,19 @@ class TDWUtils:
 
         return np.array([qx, position[1], qy])
 
+    @staticmethod
+    def euler_angles_to_rpy(euler_angles: np.array) -> np.array:
+        """
+        Convert Euler angles to ROS RPY angles.
+
+        :param euler_angles: A numpy array: `[x, y, z]` Euler angles in degrees.
+
+        :return: A numpy array: `[r, p, y]` angles in radians.
+        """
+
+        # Source: https://github.com/Unity-Technologies/URDF-Importer/blob/c41208565419b04907496baa93ad1b675d41dc20/com.unity.robotics.urdf-importer/Runtime/Extensions/TransformExtensions.cs#L85-L92
+        return np.radians(np.array([-euler_angles[2], euler_angles[0], -euler_angles[1]]))
+
 
 class AudioUtils:
     """
